/*
 * Copyright (C) 2009  Thomas "Heinervdm" Zimmermann <zimmermannn@vdm-design.de>
 *
 * This file is part of fmWettbewerb
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package de.heinervdm.fmwettbewerb;

/**
 *
 * @author thomas
 */
public class Stone {

    final static char red = 'R';
    final static char yellow = 'Y';
    final static char green = 'G';
    final static char lila = 'L';
    final static char blue = 'B';
    final static char bomb1 = '1';
    final static char bomb2 = '2';
    final static char bomb3 = '3';
    final static char bomb4 = '4';
    final static char bomb5 = '5';
    final static char nullStone = 'X';
    private char color;

    /**
     * Returns true if Stone has same color as <code>s</code>
     * @param s The stone to compare to
     * @return true if they have the same color
     */
    public boolean equals(Stone s) {
        if (s == null || s.getColor() == nullStone) {
            return false;
        }

        char sc = s.getColor();
        if (color == sc || ((sc == bomb1 || sc == bomb2 || sc == bomb3 || sc == bomb4 || sc == bomb5) &&
                (color == bomb1 || color == bomb2 || color == bomb3 || color == bomb4 || color == bomb5))) {
            return true;
        } else {
            return false;
        }
    }

    /**
     * Checks if the stones color is the color of <code>nullStone</code>, nullStone is the color for unknown stones
     * @return true if stones color ist nullStone color
     */
    public boolean isNullStone() {
        if (color == nullStone) {
            return true;
        } else {
            return false;
        }
    }

    /**
     * Checks if the stone is a Bomb
     * @param s Stone to check
     * @return true if the stone is a Bomb
     */
    public static boolean isBomb(Stone s) {
        if (s.getColor() == bomb1 || s.getColor() == bomb2 || s.getColor() == bomb3 || s.getColor() == bomb4 || s.getColor() == bomb5) {
            return true;
        } else {
            return false;
        }
    }

    /**
     * Creates a new Stone with color <code>color</code>
     * @param color
     */
    public Stone(char color) {
        setColor(color);
    }

    /**
     * @return the color
     */
    public char getColor() {
        return color;
    }

    /**
     * @param color the color to set
     */
    public void setColor(char color) {
        this.color = color;
    }
}
